==> ve-tos-java-sdk-2.6.2-sources.jar: com/volcengine/tos/model/bucket/ListedBucket.java <==
package com.volcengine.tos.model.bucket;

import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
public class ListedBucket implements Serializable {
    @JsonProperty("CreationDate")
    private String creationDate;
    @JsonProperty("Name")
    private String name;
    @JsonProperty("Location")
    private String location;
    @JsonProperty("ExtranetEndpoint")
    private String extranetEndpoint;
    @JsonProperty("IntranetEndpoint")
    private String intranetEndpoint;

    public String getCreationDate() {
        return creationDate;
    }

    public ListedBucket setCreationDate(String creationDate) {
        this.creationDate = creationDate;
        return this;
    }

    public String getName() {
        return name;
    }

    public ListedBucket setName(String name) {
        this.name = name;
        return this;
    }

    public String getLocation() {
        return location;
    }

    public ListedBucket setLocation(String location) {
        this.location = location;
        return this;
    }

    public String getExtranetEndpoint() {
        return extranetEndpoint;
    }

    public ListedBucket setExtranetEndpoint(String extranetEndpoint) {
        this.extranetEndpoint = extranetEndpoint;
        return this;
    }

    public String getIntranetEndpoint() {
        return intranetEndpoint;
    }

    public ListedBucket setIntranetEndpoint(String intranetEndpoint) {
        this.intranetEndpoint = intranetEndpoint;
        return this;
    }

    @Override
    public String toString() {
        return "ListedBucket{" +
                "creationDate='" + creationDate + '\'' +
                ", name='" + name + '\'' +
                ", location='" + location + '\'' +
                ", extranetEndpoint='" + extranetEndpoint + '\'' +
                ", intranetEndpoint='" + intranetEndpoint + '\'' +
                '}';
    }
}

==> ve-tos-java-sdk-2.7.0-sources.jar: com/volcengine/tos/model/bucket/ListedBucket.java <==
package com.volcengine.tos.model.bucket;

import com.fasterxml.jackson.annotation.JsonProperty;

import java.io.Serializable;
public class ListedBucket implements Serializable {
    @JsonProperty("CreationDate")
    private String creationDate;
    @JsonProperty("Name")
    private String name;
    @JsonProperty("Location")
    private String location;
    @JsonProperty("ExtranetEndpoint")
    private String extranetEndpoint;
    @JsonProperty("IntranetEndpoint")
    private String intranetEndpoint;
    @JsonProperty("ProjectName")
    private String projectName;

    public String getCreationDate() {
        return creationDate;
    }

    public ListedBucket setCreationDate(String creationDate) {
        this.creationDate = creationDate;
        return this;
    }

    public String getName() {
        return name;
    }

    public ListedBucket setName(String name) {
        this.name = name;
        return this;
    }

    public String getLocation() {
        return location;
    }

    public ListedBucket setLocation(String location) {
        this.location = location;
        return this;
    }

    public String getExtranetEndpoint() {
        return extranetEndpoint;
    }

    public ListedBucket setExtranetEndpoint(String extranetEndpoint) {
        this.extranetEndpoint = extranetEndpoint;
        return this;
    }

    public String getIntranetEndpoint() {
        return intranetEndpoint;
    }

    public ListedBucket setIntranetEndpoint(String intranetEndpoint) {
        this.intranetEndpoint = intranetEndpoint;
        return this;
    }

    public String getProjectName() {
        return projectName;
    }

    public ListedBucket setProjectName(String projectName) {
        this.projectName = projectName;
        return this;
    }

    @Override
    public String toString() {
        return "ListedBucket{" +
                "creationDate='" + creationDate + '\'' +
                ", name='" + name + '\'' +
                ", location='" + location + '\'' +
                ", extranetEndpoint='" + extranetEndpoint + '\'' +
                ", intranetEndpoint='" + intranetEndpoint + '\'' +
                ", projectName='" + projectName + '\'' +
                '}';
    }
}
